@@ -481,7 +481,7 @@ QList<int> QVirtualKeyboardInputEngine::patternRecognitionModes() const
 }
 
 /*!
-    \qmlmethod QVirtualKeyboardTrace InputEngine::traceBegin(int traceId, int patternRecognitionMode, var traceCaptureDeviceInfo, var traceScreenInfo)
+    \qmlmethod Trace InputEngine::traceBegin(int traceId, int patternRecognitionMode, var traceCaptureDeviceInfo, var traceScreenInfo)
     \since QtQuick.VirtualKeyboard 2.0
 
     Starts a trace interaction with the input engine.
@@ -819,7 +819,7 @@ void QVirtualKeyboardInputEngine::timerEvent(QTimerEvent *timerEvent)
 */
 
 /*!
-    \qmlproperty QVirtualKeyboardSelectionListModel InputEngine::wordCandidateListModel
+    \qmlproperty SelectionListModel InputEngine::wordCandidateListModel
 
     Use this property to access the list model for the word candidate
     list.
